@@ -8,16 +8,20 @@ struct Args {
     input: String,
 
     /// Values of similar names
-    possible_values: Vec<String>,
+    values: Vec<String>,
+
+    /// Levenshtein Distance
+    #[clap(short, long)]
+    distance: Option<usize>,
 }
 
 fn main() {
     let args = Args::parse();
 
-    let exit_code = if args.possible_values.contains(&args.input) {
+    let exit_code = if args.values.contains(&args.input) {
         eprintln!("The same value with the `{}` input exists.", args.input);
         1
-    } else if let Some(sugg) = args.possible_values.suggest(&args.input) {
+    } else if let Some(sugg) = args.values.suggest_with_dist(&args.input, args.distance) {
         println!("The `{}` input is similar to `{}`.", args.input, sugg);
         0
     } else {
